from flask import Flask, render_template, request
from sentinelsat import SentinelAPI, read_geojson, geojson_to_wkt
from datetime import date
import os


app = Flask(__name__)
app.config["APPLICATION_ROOT"] = "/ndsi/"

PROXY_PREFIX = "https://wolfpit.net/ndsi"
CACHE_DIR = "/tmp/ndsi"

@app.route("/index.html")
def indexhtml():
    return render_template('index.html', prefix=PROXY_PREFIX)

@app.route('/', methods=['POST'])
def getvalue():
    if request.method == 'POST':
        area=request.form['wkt']
        start=request.form['from1']    
        end=request.form['to']

        # change to the directory where the Sentinel data will be downloaded
        os.chdir(CACHE_DIR) #../UI/data

        # ID: rscryosphere and Pass: cryosphere
        api = SentinelAPI('yannikmallmann', 'fernerkundung', 'https://scihub.copernicus.eu/dhus')
        # This is the WKT polygon for Zugspitze
        #footprint = "POLYGON((10.960922241210938 47.38998234483188,10.960922241210938 47.4291324348703,11.051216125488281 47.4291324348703,11.051216125488281 47.38998234483188,10.960922241210938 47.38998234483188))"
        footprint = request.form['wkt']
        date_1 = ((request.form['from1']), (request.form['to']))
        date_list = list(date_1)
        start_date = date_list[0]
        end_date = date_list[1]
        # if a month with two numbers is chosen, len(date) = 12 else 11
        if len(start_date) == 12:
            year_start = int(start_date[0:4])
            month_start = int(start_date[6:8])
            if start_date[10] == '0':
                day_start = int(start_date[11:12])
            elif not start_date[10]== '0':
                day_start = int(start_date[10:12])
            day_start = int(start_date[10:12])
        elif len(start_date) == 11:
            year_start = int(start_date[0:4])
            month_start = int(start_date[6:7])
            if start_date[9] == '0':
                day_start = int(start_date[10:11])
            elif not start_date[9] == '0':
                day_start = int(start_date[9:11])
        if len(end_date) == 12:
            year_end = int(end_date[0:4])
            month_end = int(end_date[6:8])
            if end_date[10] == '0':
                day_end = int(end_date[11:12])
            elif not end_date[10]== '0':
                day_end = int(end_date[10:12])
            day_end = int(end_date[10:12])
        elif len(end_date) == 11:
            year_end = int(end_date[0:4])
            month_end = int(end_date[6:7])
            if end_date[9] == '0':
                day_end = int(end_date[10:11])
            elif not end_date[9] == '0':
                day_end = int(end_date[9:11])    
       
        # the date format is date = (from_date,to_date). date(yyyy,mm,dd)
        products = api.query(footprint,
                            #date=(date(2016, 3, 10), date(2016, 3, 16)), 
                            date= (date(year_start, month_start, day_start), date(year_end, month_end, day_end)),
                            platformname='Sentinel-2', # you can also search Sentinel-1 datasets: 'Sentinel-1'
                            producttype="S2MSI2A") # you can also search Sentinel-2 datasets product type: 'S2MSI1C' or 'S2MSI2A'

        #displays the list of products
        # https://scihub.copernicus.eu/userguide/BatchScripting
        # uuid of the product can be usd with wget
        print(products) # this is the list of the available satellite scene. go to the variable explorer to see the number of scenes

        #download product
        api.download_all(products) # Keep this commented unless you are ready to download the products


        return render_template('pass.html', prefix=PROXY_PREFIX, a=area, start=start, end=end)


@app.route("/help.html")
def helphtml():
    return render_template('help.html', prefix=PROXY_PREFIX)

if __name__ == "__main__":
    app.run()
